==> blue2-the-circle-1.0.56-564bab.tar: assets/scripts/common.js <==
import { fontawesome, throttle } from './utils';
import Swiper from 'swiper';

const nav = {
    breakpoint: 992,
    isOpen: false,
    lastWidth: window.innerWidth,
    el: {
        scrollEl:   document.documentElement,
        toggle:     document.querySelector('.l-nav__toggle'),
        nav:        document.querySelector('.l-nav'),
        header:     document.querySelector('.l-header'),
    },
    init: () => {
        nav.el.toggle.addEventListener('click', nav.toggle);
        window.addEventListener('resize', nav.resize);
    },

    toggle: () => {
        const isOpen = nav.el.toggle.getAttribute('data-state') === 'open';
        if (isOpen) {
            nav.close();
        } else {
            nav.open();
        }
    },

    open: () => {
        nav.el.scrollEl.style.overflow = 'hidden';
        nav.el.header.setAttribute('data-state', 'open');
        nav.el.nav.setAttribute('data-state', 'open');
        nav.el.toggle.setAttribute('data-state', 'open');
        nav.el.toggle.setAttribute('aria-expanded', 'true');
        nav.el.toggle.setAttribute('aria-label', 'Close primary navigation');
        nav.el.nav.focus();
        nav.isOpen = true;
    },

    close: () => {
        nav.el.scrollEl.style.overflow = null;
        nav.el.header.setAttribute('data-state', 'closed');
        nav.el.nav.setAttribute('data-state', 'closed');
        nav.el.toggle.setAttribute('data-state', 'closed');
        nav.el.toggle.setAttribute('aria-expanded', 'false');
        nav.el.toggle.setAttribute('aria-label', 'Open primary navigation');
        nav.el.toggle.focus();
        nav.isOpen = false;
    },

    resize: throttle(() => {
        const currentWidth = window.innerWidth;
        // going from below breakpoint to above
        if (nav.lastWidth <= nav.breakpoint && currentWidth > nav.breakpoint) {
            // if nav open, close it
            if (nav.isOpen) {
                nav.close();
            }
        }
        nav.lastWidth = currentWidth;
    }, 1000)
};

const common = () => {
    nav.init();
    fontawesome();

    function formUpdate() {
        let checker = false;
        let checkCount = 0;
        checker = setInterval(function() {
            checkCount++;
            if ($('.timeslot-lists.ts-grid-container li').length > 0 || checkCount > 15) {
                clearInterval(checker);
                checkCount = 0;
                // Select the target node.
                const target = $(document).find('#show_time_slot')[0];
                // Create an observer instance.
                const observer = new MutationObserver(function(mutations) {
                    $('.timeslot-lists.ts-grid-container li').each(function(i,j) {
                        const currTxt = $(j).find('a')
                            .text();
                        if (currTxt === '09:00 - 13:00') {
                            //half day morning
                            $(j).find('a')
                                .html(`<input type="radio" name="time_slots" value="${currTxt}" class="time_slot">Half day (${currTxt})`);
                            $(j).appendTo('.timeslot-lists.ts-grid-container');
                        }
                        if (currTxt === '13:00 - 17:00') {
                            //half day afternoon
                            $(j).find('a')
                                .html(`<input type="radio" name="time_slots" value="${currTxt}" class="time_slot">Half day (${currTxt})`);
                            $(j).appendTo('.timeslot-lists.ts-grid-container');
                        }
                        if (currTxt === '09:00 - 17:00') {
                            //full day
                            $(j).find('a')
                                .html(`<input type="radio" name="time_slots" value="${currTxt}" class="time_slot">Full day (${currTxt})`);
                            $(j).appendTo('.timeslot-lists.ts-grid-container');
                        }
                    });
                });

                // Pass in the target node, as well as the observer options.
                observer.observe(target, {
                    attributes:    true,
                    childList:     true,
                    characterData: true
                });

                $('.timeslot-lists.ts-grid-container li').each(function(i,j) {
                    const currTxt = $(j).find('a')
                        .text();
                    if (currTxt === '09:00 - 13:00') {
                        //half day morning
                        $(j).find('a')
                            .html(`<input type="radio" name="time_slots" value="${currTxt}" class="time_slot">Half day (${currTxt})`);
                        $(j).appendTo('.timeslot-lists.ts-grid-container');
                    }
                    if (currTxt === '13:00 - 17:00') {
                        //half day afternoon
                        $(j).find('a')
                            .html(`<input type="radio" name="time_slots" value="${currTxt}" class="time_slot">Half day (${currTxt})`);
                        $(j).appendTo('.timeslot-lists.ts-grid-container');
                    }
                    if (currTxt === '09:00 - 17:00') {
                        //full day
                        $(j).find('a')
                            .html(`<input type="radio" name="time_slots" value="${currTxt}" class="time_slot">Full day (${currTxt})`);
                        $(j).appendTo('.timeslot-lists.ts-grid-container');
                    }
                });
            }
        }, 200);
    }

    if ($('#hero-video').hasClass('autoplay') && window.innerWidth > 767) {
        $('#hero-video')[0].play();
        $('#hero-video').attr('data-status','play');
    }


    if ($('#bkap-booking-form').length > 0) {
        formUpdate();
        $(document).on('click', '#inline_calendar', function() {
            formUpdate();
        });
    }

    $('#video-toggle').click(function() {
        const video = $('#hero-video');
        const status = video.attr('data-status');
        if (status === 'paused') {
            video[0].play();
            video.attr('data-status', 'play');
        } else {
            video[0].pause();
            video.attr('data-status', 'paused');
        }
        const icon = $('.action-toggle').find('svg');
        const iconFaIcon = icon.attr('data-icon');
        const actionText = $('.action .text');
        iconFaIcon === 'play' ? icon.attr('data-icon', 'pause') : icon.attr('data-icon', 'play');
        actionText.text() === 'Play video' ? actionText.text('Pause video') : actionText.text('Play video');
    });

    if ($('.logo-slider-section').length) {
        const logoSlider = new Swiper('.logo-slider-section .swiper-container', {
            autoplay: {
                delay: 1000,
            },
            loop: true,
            lazy: true,
            loopAdditionalSlides: 6,
            breakpoints: {
                0: {
                    slidesPerView: 2,
                    spaceBetween: 50
                },
                450: {
                    slidesPerView: 3,
                    spaceBetween: 50
                },
                768: {
                    slidesPerView: 4,
                    spaceBetween: 50
                },
                992: {
                    slidesPerView: 5,
                    spaceBetween: 50
                },
                1200: {
                    spaceBetween: 50,
                    slidesPerView: 6,
                }
            },
        });

        $('.logo-slider-section .swiper-container').hover(function() {
            logoSlider.autoplay.stop();
        }, function() {
            logoSlider.autoplay.start();
        });
    }

    if ($('#teamModal').length) {
        $('#teamModal').on('show.bs.modal', function(event) {
            const teamMember = $(event.relatedTarget);
            const name = teamMember.data('name');
            const title = teamMember.data('title');
            const desc = teamMember.data('description');
            const modal = $(this);
            modal.find('.modal-title').text(name);
            modal.find('.title').text(title);
            modal.find('.description').html(desc);
        });
    }
};

export default common;

==> blue2-the-circle-1.0.61-4312a6.tar: assets/scripts/common.js <==
import { fontawesome, throttle } from './utils';
import Swiper from 'swiper';
import LIGHTBOX from './lightbox';

const nav = {
    breakpoint: 992,
    isOpen: false,
    lastWidth: window.innerWidth,
    el: {
        scrollEl:   document.documentElement,
        toggle:     document.querySelector('.l-nav__toggle'),
        nav:        document.querySelector('.l-nav'),
        header:     document.querySelector('.l-header'),
    },
    init: () => {
        nav.el.toggle.addEventListener('click', nav.toggle);
        window.addEventListener('resize', nav.resize);
    },

    toggle: () => {
        const isOpen = nav.el.toggle.getAttribute('data-state') === 'open';
        if (isOpen) {
            nav.close();
        } else {
            nav.open();
        }
    },

    open: () => {
        nav.el.scrollEl.style.overflow = 'hidden';
        nav.el.header.setAttribute('data-state', 'open');
        nav.el.nav.setAttribute('data-state', 'open');
        nav.el.toggle.setAttribute('data-state', 'open');
        nav.el.toggle.setAttribute('aria-expanded', 'true');
        nav.el.toggle.setAttribute('aria-label', 'Close primary navigation');
        nav.el.nav.focus();
        nav.isOpen = true;
    },

    close: () => {
        nav.el.scrollEl.style.overflow = null;
        nav.el.header.setAttribute('data-state', 'closed');
        nav.el.nav.setAttribute('data-state', 'closed');
        nav.el.toggle.setAttribute('data-state', 'closed');
        nav.el.toggle.setAttribute('aria-expanded', 'false');
        nav.el.toggle.setAttribute('aria-label', 'Open primary navigation');
        nav.el.toggle.focus();
        nav.isOpen = false;
    },

    resize: throttle(() => {
        const currentWidth = window.innerWidth;
        // going from below breakpoint to above
        if (nav.lastWidth <= nav.breakpoint && currentWidth > nav.breakpoint) {
            // if nav open, close it
            if (nav.isOpen) {
                nav.close();
            }
        }
        nav.lastWidth = currentWidth;
    }, 1000)
};

const common = () => {
    nav.init();
    fontawesome();

    function formUpdate() {
        let checker = false;
        let checkCount = 0;
        checker = setInterval(function() {
            checkCount++;
            if ($('.timeslot-lists.ts-grid-container li').length > 0 || checkCount > 15) {
                clearInterval(checker);
                checkCount = 0;
                // Select the target node.
                const target = $(document).find('#show_time_slot')[0];
                // Create an observer instance.
                const observer = new MutationObserver(function(mutations) {
                    $('.timeslot-lists.ts-grid-container li').each(function(i,j) {
                        const currTxt = $(j).find('a')
                            .text();
                        if (currTxt === '09:00 - 13:00') {
                            //half day morning
                            $(j).find('a')
                                .html(`<input type="radio" name="time_slots" value="${currTxt}" class="time_slot">Half day (${currTxt})`);
                            $(j).appendTo('.timeslot-lists.ts-grid-container');
                        }
                        if (currTxt === '13:00 - 17:00') {
                            //half day afternoon
                            $(j).find('a')
                                .html(`<input type="radio" name="time_slots" value="${currTxt}" class="time_slot">Half day (${currTxt})`);
                            $(j).appendTo('.timeslot-lists.ts-grid-container');
                        }
                        if (currTxt === '09:00 - 17:00') {
                            //full day
                            $(j).find('a')
                                .html(`<input type="radio" name="time_slots" value="${currTxt}" class="time_slot">Full day (${currTxt})`);
                            $(j).appendTo('.timeslot-lists.ts-grid-container');
                        }
                    });
                });

                // Pass in the target node, as well as the observer options.
                observer.observe(target, {
                    attributes:    true,
                    childList:     true,
                    characterData: true
                });

                $('.timeslot-lists.ts-grid-container li').each(function(i,j) {
                    const currTxt = $(j).find('a')
                        .text();
                    if (currTxt === '09:00 - 13:00') {
                        //half day morning
                        $(j).find('a')
                            .html(`<input type="radio" name="time_slots" value="${currTxt}" class="time_slot">Half day (${currTxt})`);
                        $(j).appendTo('.timeslot-lists.ts-grid-container');
                    }
                    if (currTxt === '13:00 - 17:00') {
                        //half day afternoon
                        $(j).find('a')
                            .html(`<input type="radio" name="time_slots" value="${currTxt}" class="time_slot">Half day (${currTxt})`);
                        $(j).appendTo('.timeslot-lists.ts-grid-container');
                    }
                    if (currTxt === '09:00 - 17:00') {
                        //full day
                        $(j).find('a')
                            .html(`<input type="radio" name="time_slots" value="${currTxt}" class="time_slot">Full day (${currTxt})`);
                        $(j).appendTo('.timeslot-lists.ts-grid-container');
                    }
                });
            }
        }, 200);
    }

    if ($('#hero-video').hasClass('autoplay') && window.innerWidth > 767) {
        $('#hero-video')[0].play();
        $('#hero-video').attr('data-status','play');
    }


    if ($('#bkap-booking-form').length > 0) {
        formUpdate();
        $(document).on('click', '#inline_calendar', function() {
            formUpdate();
        });
    }

    $('#video-toggle').click(function() {
        const video = $('#hero-video');
        const status = video.attr('data-status');
        if (status === 'paused') {
            video[0].play();
            video.attr('data-status', 'play');
        } else {
            video[0].pause();
            video.attr('data-status', 'paused');
        }
        const icon = $('.action-toggle').find('svg');
        const iconFaIcon = icon.attr('data-icon');
        const actionText = $('.action .text');
        iconFaIcon === 'play' ? icon.attr('data-icon', 'pause') : icon.attr('data-icon', 'play');
        actionText.text() === 'Play video' ? actionText.text('Pause video') : actionText.text('Play video');
    });

    if ($('.logo-slider-section').length) {
        const logoSlider = new Swiper('.logo-slider-section .swiper-container', {
            autoplay: {
                delay: 1000,
            },
            loop: true,
            lazy: true,
            loopAdditionalSlides: 6,
            breakpoints: {
                0: {
                    slidesPerView: 2,
                    spaceBetween: 50
                },
                450: {
                    slidesPerView: 3,
                    spaceBetween: 50
                },
                768: {
                    slidesPerView: 4,
                    spaceBetween: 50
                },
                992: {
                    slidesPerView: 5,
                    spaceBetween: 50
                },
                1200: {
                    spaceBetween: 50,
                    slidesPerView: 6,
                }
            },
        });

        $('.logo-slider-section .swiper-container').hover(function() {
            logoSlider.autoplay.stop();
        }, function() {
            logoSlider.autoplay.start();
        });
    }

    if ($('#teamModal').length) {
        $('#teamModal').on('show.bs.modal', function(event) {
            const teamMember = $(event.relatedTarget);
            const name = teamMember.data('name');
            const title = teamMember.data('title');
            const desc = teamMember.data('description');
            const modal = $(this);
            modal.find('.modal-title').text(name);
            modal.find('.title').text(title);
            modal.find('.description').html(desc);
        });
    }

    // lightbox
    LIGHTBOX.instance = $('<div />')
        .addClass('lightbox-container')
        .appendTo('body')
        .on('click', LIGHTBOX.onHide);

    const container = LIGHTBOX.instance;

    const slider = $('<div />')
        .addClass('lightbox-slider')
        .appendTo(container)
        .on('click', function(evt) {
            evt.stopPropagation();
        });

    const items = $('.lightbox-gallery .gallery-grid .gallery-item').on('click', LIGHTBOX.onClick);

    for (let i = 0; i < items.length; i++) {
        const src = items.eq(i)
            .find('img')
            .prop('src');

        $('<div />')
            .addClass('lightbox-item')
            .css('background-image', `url(${src})`)
            .appendTo(slider);

        LIGHTBOX.images.push(src);
    }

    const prev = $('<div />')
        .addClass('lightbox-prev')
        .html('<i class="fas fa-chevron-left"></i>')
        .prependTo(slider)
        .on('click', LIGHTBOX.onPrev);

    const next = $('<div />')
        .addClass('lightbox-next')
        .html('<i class=\"fas fa-chevron-right\"></i>')
        .appendTo(slider)
        .on('click', LIGHTBOX.onNext);
    const closeLightboxButton = $('<div class="close-lightbox"><i class="fas fa-times"></i></div>')
        .appendTo(container);
};

export default common;
